==> docx4j-openxml-objects-8.3.3-sources.jar: org/docx4j/org/w3/x2003/inkML/ObjectFactory.java <==

package org.docx4j.org.w3.x2003.inkML;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.docx4j.org.w3.x2003.inkML package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Ink_QNAME = new QName("http://www.w3.org/2003/InkML", "ink");
    private final static QName _Trace_QNAME = new QName("http://www.w3.org/2003/InkML", "trace");
    private final static QName _TraceView_QNAME = new QName("http://www.w3.org/2003/InkML", "traceView");
    private final static QName _Definitions_QNAME = new QName("http://www.w3.org/2003/InkML", "definitions");
    private final static QName _MappingTypeBind_QNAME = new QName("http://www.w3.org/2003/InkML", "bind");
    private final static QName _MappingTypeTable_QNAME = new QName("http://www.w3.org/2003/InkML", "table");
    private final static QName _MappingTypeAffine_QNAME = new QName("http://www.w3.org/2003/InkML", "affine");
    private final static QName _MappingTypeMapping_QNAME = new QName("http://www.w3.org/2003/InkML", "mapping");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.docx4j.org.w3.x2003.inkML
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ChannelPropertiesType }
     * 
     */
    public ChannelPropertiesType createChannelPropertiesType() {
        return new ChannelPropertiesType();
    }

    /**
     * Create an instance of {@link InkType }
     * 
     */
    public InkType createInkType() {
        return new InkType();
    }

    /**
     * Create an instance of {@link TraceType }
     * 
     */
    public TraceType createTraceType() {
        return new TraceType();
    }

    /**
     * Create an instance of {@link TraceViewType }
     * 
     */
    public TraceViewType createTraceViewType() {
        return new TraceViewType();
    }

    /**
     * Create an instance of {@link DefinitionsType }
     * 
     */
    public DefinitionsType createDefinitionsType() {
        return new DefinitionsType();
    }

    /**
     * Create an instance of {@link BrushPropertyType }
     * 
     */
    public BrushPropertyType createBrushPropertyType() {
        return new BrushPropertyType();
    }

    /**
     * Create an instance of {@link ContextType }
     * 
     */
    public ContextType createContextType() {
        return new ContextType();
    }

    /**
     * Create an instance of {@link TraceFormatType }
     * 
     */
    public TraceFormatType createTraceFormatType() {
        return new TraceFormatType();
    }

    /**
     * Create an instance of {@link InkSourceType }
     * 
     */
    public InkSourceType createInkSourceType() {
        return new InkSourceType();
    }

    /**
     * Create an instance of {@link SampleRateType }
     * 
     */
    public SampleRateType createSampleRateType() {
        return new SampleRateType();
    }

    /**
     * Create an instance of {@link LatencyType }
     * 
     */
    public LatencyType createLatencyType() {
        return new LatencyType();
    }

    /**
     * Create an instance of {@link ActiveAreaType }
     * 
     */
    public ActiveAreaType createActiveAreaType() {
        return new ActiveAreaType();
    }

    /**
     * Create an instance of {@link SourcePropertyType }
     * 
     */
    public SourcePropertyType createSourcePropertyType() {
        return new SourcePropertyType();
    }

    /**
     * Create an instance of {@link IntermittentChannelsType }
     * 
     */
    public IntermittentChannelsType createIntermittentChannelsType() {
        return new IntermittentChannelsType();
    }

    /**
     * Create an instance of {@link ChannelType }
     * 
     */
    public ChannelType createChannelType() {
        return new ChannelType();
    }

    /**
     * Create an instance of {@link CanvasType }
     * 
     */
    public CanvasType createCanvasType() {
        return new CanvasType();
    }

    /**
     * Create an instance of {@link CanvasTransformType }
     * 
     */
    public CanvasTransformType createCanvasTransformType() {
        return new CanvasTransformType();
    }

    /**
     * Create an instance of {@link TimestampType }
     * 
     */
    public TimestampType createTimestampType() {
        return new TimestampType();
    }

    /**
     * Create an instance of {@link MappingType }
     * 
     */
    public MappingType createMappingType() {
        return new MappingType();
    }

    /**
     * Create an instance of {@link BindType }
     * 
     */
    public BindType createBindType() {
        return new BindType();
    }

    /**
     * Create an instance of {@link TableType }
     * 
     */
    public TableType createTableType() {
        return new TableType();
    }

    /**
     * Create an instance of {@link AffineType }
     * 
     */
    public AffineType createAffineType() {
        return new AffineType();
    }

    /**
     * Create an instance of {@link BrushType }
     * 
     */
    public BrushType createBrushType() {
        return new BrushType();
    }

    /**
     * Create an instance of {@link TraceGroupType }
     * 
     */
    public TraceGroupType createTraceGroupType() {
        return new TraceGroupType();
    }

    /**
     * Create an instance of {@link AnnotationType }
     * 
     */
    public AnnotationType createAnnotationType() {
        return new AnnotationType();
    }

    /**
     * Create an instance of {@link AnnotationXMLType }
     * 
     */
    public AnnotationXMLType createAnnotationXMLType() {
        return new AnnotationXMLType();
    }

    /**
     * Create an instance of {@link CTMatrix }
     * 
     */
    public CTMatrix createCTMatrix() {
        return new CTMatrix();
    }

    /**
     * Create an instance of {@link ChannelPropertiesType.ChannelProperty }
     * 
     */
    public ChannelPropertiesType.ChannelProperty createChannelPropertiesTypeChannelProperty() {
        return new ChannelPropertiesType.ChannelProperty();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InkType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "ink")
    public JAXBElement<InkType> createInk(InkType value) {
        return new JAXBElement<InkType>(_Ink_QNAME, InkType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TraceType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "trace")
    public JAXBElement<TraceType> createTrace(TraceType value) {
        return new JAXBElement<TraceType>(_Trace_QNAME, TraceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TraceViewType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "traceView")
    public JAXBElement<TraceViewType> createTraceView(TraceViewType value) {
        return new JAXBElement<TraceViewType>(_TraceView_QNAME, TraceViewType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DefinitionsType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "definitions")
    public JAXBElement<DefinitionsType> createDefinitions(DefinitionsType value) {
        return new JAXBElement<DefinitionsType>(_Definitions_QNAME, DefinitionsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BindType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "bind", scope = MappingType.class)
    public JAXBElement<BindType> createMappingTypeBind(BindType value) {
        return new JAXBElement<BindType>(_MappingTypeBind_QNAME, BindType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TableType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "table", scope = MappingType.class)
    public JAXBElement<TableType> createMappingTypeTable(TableType value) {
        return new JAXBElement<TableType>(_MappingTypeTable_QNAME, TableType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AffineType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "affine", scope = MappingType.class)
    public JAXBElement<AffineType> createMappingTypeAffine(AffineType value) {
        return new JAXBElement<AffineType>(_MappingTypeAffine_QNAME, AffineType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MappingType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "mapping", scope = MappingType.class)
    public JAXBElement<MappingType> createMappingTypeMapping(MappingType value) {
        return new JAXBElement<MappingType>(_MappingTypeMapping_QNAME, MappingType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MappingType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "mapping", scope = CanvasTransformType.class)
    public JAXBElement<MappingType> createCanvasTransformTypeMapping(MappingType value) {
        return new JAXBElement<MappingType>(_MappingTypeMapping_QNAME, MappingType.class, CanvasTransformType.class, value);
    }

}

==> docx4j-openxml-objects-11.5.3-sources.jar: org/docx4j/org/w3/x2003/inkML/ObjectFactory.java <==

package org.docx4j.org.w3.x2003.inkML;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.docx4j.org.w3.x2003.inkML package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Ink_QNAME = new QName("http://www.w3.org/2003/InkML", "ink");
    private final static QName _Trace_QNAME = new QName("http://www.w3.org/2003/InkML", "trace");
    private final static QName _TraceView_QNAME = new QName("http://www.w3.org/2003/InkML", "traceView");
    private final static QName _Definitions_QNAME = new QName("http://www.w3.org/2003/InkML", "definitions");
    private final static QName _MappingTypeBind_QNAME = new QName("http://www.w3.org/2003/InkML", "bind");
    private final static QName _MappingTypeTable_QNAME = new QName("http://www.w3.org/2003/InkML", "table");
    private final static QName _MappingTypeAffine_QNAME = new QName("http://www.w3.org/2003/InkML", "affine");
    private final static QName _MappingTypeMapping_QNAME = new QName("http://www.w3.org/2003/InkML", "mapping");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.docx4j.org.w3.x2003.inkML
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ChannelPropertiesType }
     * 
     */
    public ChannelPropertiesType createChannelPropertiesType() {
        return new ChannelPropertiesType();
    }

    /**
     * Create an instance of {@link InkType }
     * 
     */
    public InkType createInkType() {
        return new InkType();
    }

    /**
     * Create an instance of {@link TraceType }
     * 
     */
    public TraceType createTraceType() {
        return new TraceType();
    }

    /**
     * Create an instance of {@link TraceViewType }
     * 
     */
    public TraceViewType createTraceViewType() {
        return new TraceViewType();
    }

    /**
     * Create an instance of {@link DefinitionsType }
     * 
     */
    public DefinitionsType createDefinitionsType() {
        return new DefinitionsType();
    }

    /**
     * Create an instance of {@link BrushPropertyType }
     * 
     */
    public BrushPropertyType createBrushPropertyType() {
        return new BrushPropertyType();
    }

    /**
     * Create an instance of {@link ContextType }
     * 
     */
    public ContextType createContextType() {
        return new ContextType();
    }

    /**
     * Create an instance of {@link TraceFormatType }
     * 
     */
    public TraceFormatType createTraceFormatType() {
        return new TraceFormatType();
    }

    /**
     * Create an instance of {@link InkSourceType }
     * 
     */
    public InkSourceType createInkSourceType() {
        return new InkSourceType();
    }

    /**
     * Create an instance of {@link SampleRateType }
     * 
     */
    public SampleRateType createSampleRateType() {
        return new SampleRateType();
    }

    /**
     * Create an instance of {@link LatencyType }
     * 
     */
    public LatencyType createLatencyType() {
        return new LatencyType();
    }

    /**
     * Create an instance of {@link ActiveAreaType }
     * 
     */
    public ActiveAreaType createActiveAreaType() {
        return new ActiveAreaType();
    }

    /**
     * Create an instance of {@link SourcePropertyType }
     * 
     */
    public SourcePropertyType createSourcePropertyType() {
        return new SourcePropertyType();
    }

    /**
     * Create an instance of {@link IntermittentChannelsType }
     * 
     */
    public IntermittentChannelsType createIntermittentChannelsType() {
        return new IntermittentChannelsType();
    }

    /**
     * Create an instance of {@link ChannelType }
     * 
     */
    public ChannelType createChannelType() {
        return new ChannelType();
    }

    /**
     * Create an instance of {@link CanvasType }
     * 
     */
    public CanvasType createCanvasType() {
        return new CanvasType();
    }

    /**
     * Create an instance of {@link CanvasTransformType }
     * 
     */
    public CanvasTransformType createCanvasTransformType() {
        return new CanvasTransformType();
    }

    /**
     * Create an instance of {@link TimestampType }
     * 
     */
    public TimestampType createTimestampType() {
        return new TimestampType();
    }

    /**
     * Create an instance of {@link MappingType }
     * 
     */
    public MappingType createMappingType() {
        return new MappingType();
    }

    /**
     * Create an instance of {@link BindType }
     * 
     */
    public BindType createBindType() {
        return new BindType();
    }

    /**
     * Create an instance of {@link TableType }
     * 
     */
    public TableType createTableType() {
        return new TableType();
    }

    /**
     * Create an instance of {@link AffineType }
     * 
     */
    public AffineType createAffineType() {
        return new AffineType();
    }

    /**
     * Create an instance of {@link BrushType }
     * 
     */
    public BrushType createBrushType() {
        return new BrushType();
    }

    /**
     * Create an instance of {@link TraceGroupType }
     * 
     */
    public TraceGroupType createTraceGroupType() {
        return new TraceGroupType();
    }

    /**
     * Create an instance of {@link AnnotationType }
     * 
     */
    public AnnotationType createAnnotationType() {
        return new AnnotationType();
    }

    /**
     * Create an instance of {@link AnnotationXMLType }
     * 
     */
    public AnnotationXMLType createAnnotationXMLType() {
        return new AnnotationXMLType();
    }

    /**
     * Create an instance of {@link CTMatrix }
     * 
     */
    public CTMatrix createCTMatrix() {
        return new CTMatrix();
    }

    /**
     * Create an instance of {@link ChannelPropertiesType.ChannelProperty }
     * 
     */
    public ChannelPropertiesType.ChannelProperty createChannelPropertiesTypeChannelProperty() {
        return new ChannelPropertiesType.ChannelProperty();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InkType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "ink")
    public JAXBElement<InkType> createInk(InkType value) {
        return new JAXBElement<InkType>(_Ink_QNAME, InkType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TraceType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "trace")
    public JAXBElement<TraceType> createTrace(TraceType value) {
        return new JAXBElement<TraceType>(_Trace_QNAME, TraceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TraceViewType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "traceView")
    public JAXBElement<TraceViewType> createTraceView(TraceViewType value) {
        return new JAXBElement<TraceViewType>(_TraceView_QNAME, TraceViewType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DefinitionsType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "definitions")
    public JAXBElement<DefinitionsType> createDefinitions(DefinitionsType value) {
        return new JAXBElement<DefinitionsType>(_Definitions_QNAME, DefinitionsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BindType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "bind", scope = MappingType.class)
    public JAXBElement<BindType> createMappingTypeBind(BindType value) {
        return new JAXBElement<BindType>(_MappingTypeBind_QNAME, BindType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TableType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "table", scope = MappingType.class)
    public JAXBElement<TableType> createMappingTypeTable(TableType value) {
        return new JAXBElement<TableType>(_MappingTypeTable_QNAME, TableType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AffineType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "affine", scope = MappingType.class)
    public JAXBElement<AffineType> createMappingTypeAffine(AffineType value) {
        return new JAXBElement<AffineType>(_MappingTypeAffine_QNAME, AffineType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MappingType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "mapping", scope = MappingType.class)
    public JAXBElement<MappingType> createMappingTypeMapping(MappingType value) {
        return new JAXBElement<MappingType>(_MappingTypeMapping_QNAME, MappingType.class, MappingType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MappingType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2003/InkML", name = "mapping", scope = CanvasTransformType.class)
    public JAXBElement<MappingType> createCanvasTransformTypeMapping(MappingType value) {
        return new JAXBElement<MappingType>(_MappingTypeMapping_QNAME, MappingType.class, CanvasTransformType.class, value);
    }

}
